"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const SecretsStorageSingleton_1 = require("../cache/secrets/SecretsStorageSingleton");
const core_1 = require("../config/core");
const logger_1 = require("../logger");
const dwc_1 = require("./dwc");
const utils_1 = require("./utils");
const run = async () => {
    const { error, debug, output } = (0, logger_1.get)("dwc.run");
    let exitCode = 0;
    try {
        await (0, dwc_1.init)();
        await (0, utils_1.checkVersion)();
        await (0, dwc_1.executeCommand)();
    }
    catch (err) {
        if (err.code === "commander.helpDisplayed" ||
            err.code === "commander.version") {
            debug("Error while running CLI", err.stack);
        }
        else {
            error("Error while running CLI", err.stack);
            exitCode = 1;
        }
        exitCode = err.exitCode ?? exitCode;
    }
    finally {
        await (0, utils_1.compareEtags)();
        if ((0, core_1.isDeprecated)()) {
            const message = (0, core_1.getDeprecationMessage)() ??
                "WARNING: This package has been deprecated. Please consult the README or CHANGELOG for more information.";
            output(message);
        }
        await SecretsStorageSingleton_1.SecretsStorageSingleton.SINGLETON.synchronizeSecretsToStorage();
        (0, utils_1.verifyNodeVersion)();
        if (exitCode > 0) {
            process.exit(exitCode);
        }
    }
};
exports.run = run;
